@@ -5,11 +5,11 @@ use warnings;
 package MooX::Press;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.003';
+our $VERSION   = '0.004';
 
 use Exporter::Tiny qw(mkopt);
 use Scalar::Util qw(blessed);
-# also depends on Moo, Type::Tiny, and Module::Runtime
+use namespace::autoclean;
 
 my $_expand = sub {
 	return unless defined $_[0];
@@ -48,9 +48,14 @@ sub import {
 	my $builder = shift;
 	my $caller  = caller;
 	my %opts    = @_==1 ? $_expand->(shift) : @_;
-	$opts{prefix} = $caller unless exists $opts{prefix};
-	$opts{toolkit} ||= $ENV{'PERL_MOOX_PRESS_TOOLKIT'} || 'Moo';
 	$opts{caller}  ||= $caller;
+	$opts{prefix} = $opts{caller} unless exists $opts{prefix};
+	$opts{toolkit} ||= $ENV{'PERL_MOOX_PRESS_TOOLKIT'} || 'Moo';
+	
+	$opts{version} = $opts{caller}->VERSION
+		unless exists $opts{version};
+	$opts{authority} = do { no strict 'refs'; no warnings 'once'; ${$opts{caller}."::AUTHORITY"} }
+		unless exists $opts{authority};
 	
 	# Sucks that we need to go through the lists thrice, but we really need to
 	# pre-build the type library so it can be used in `isa` for classes/roles.
@@ -62,7 +67,7 @@ sub import {
 	$opts{type_library} = $builder->qualify_name($opts{type_library}, $opts{prefix});
 	
 	if ($opts{type_library}) {
-		$builder->prepare_type_library($opts{type_library});
+		$builder->prepare_type_library($opts{type_library}, $opts{version}, $opts{authority});
 	}
 	
 	for my $role (@roles) {
@@ -120,7 +125,7 @@ sub croak {
 my $none;
 sub prepare_type_library {
 	my $builder = shift;
-	my ($lib) = @_;
+	my ($lib, $version, $authority) = @_;
 	my %types_hash;
 	require Type::Tiny::Role;
 	require Type::Tiny::Class;
@@ -150,8 +155,11 @@ sub prepare_type_library {
 		$types_hash{$kind}{$target};
 	};
 	no strict 'refs';
+	no warnings 'once';
 	*{"$lib\::_mooxpress_add_type"} = $adder;
 	*{"$lib\::get_type_for_package"} = $getter;
+	${"$lib\::VERSION"} = $version if defined $version;
+	${"$lib\::AUTHORITY"} = $authority if defined $authority;
 }
 
 sub make_type_for_role {
@@ -311,6 +319,14 @@ sub _make_package {
 			$builder->$method($qname, \@isa);
 		}
 	}
+
+	for my $var (qw/VERSION AUTHORITY/) {
+		if (defined $opts{lc $var}) {
+			no strict 'refs';
+			no warnings 'once';
+			${"$qname\::$var"} = $opts{lc $var};
+		}
+	}
 	
 	{
 		my $method = $opts{toolkit_apply_roles} || ("apply_roles_".lc $toolkit);
@@ -708,6 +724,20 @@ for classes, but see L</Role Options>.
 The strings "Moo", "Moose", or "Mouse" are accepted and instruct MooX::Press
 to use your favourite OO toolkit. "Moo" is the default.
 
+=item C<< version >> I<< (Num) >>
+
+This has nothing to do with the version of MooX::Press you are using.
+It sets the C<< our $VERSION >> variable for the classes and roles being
+generated.
+
+=item C<< authority >> I<< (Str) >>
+
+This sets the C<< our $AUTHORITY >> variable for the classes and roles being
+generated.
+
+C<version> and C<authority> will be copied from the caller if they are not set,
+but you can set them to undef explicitly if you want to avoid that.
+
 =item C<< prefix >> I<< (Str|Undef) >>
 
 A namespace prefix for MooX::Press to put all your classes into. If MooX::Press
@@ -1152,6 +1182,14 @@ C<< ABC::XYZ->new_foo_bar() >>, and a type constraint
 
 Override toolkit choice for this class and any child classes.
 
+=item C<< version >> I<< (Num) >>
+
+Override version number for this class and any child classes.
+
+=item C<< authority >> I<< (Str) >>
+
+Override authority for this class and any child classes.
+
 See L</Import Options>.
 
 =item C<< prefix >> I<< (Str) >>
